========================
Authors and contributors
========================

The following people have contributed code and/or ideas to the current version
of Neo. The institutional affiliations are those at the time of the contribution,
and may not be the current affiliation of a contributor.

* Samuel Garcia [1]
* Andrew Davison [2]
* Chris Rodgers [3]
* Pierre Yger [2]
* Yann Mahnoun [4]
* Luc Estabanez [2]
* Andrey Sobolev [5]
* Thierry Brizzi [2]
* Florent Jaillet [6]
* Philipp Rautenberg [5]
* Thomas Wachtler [5]
* Cyril Dejean [7]
* Robert Pröpper [8]

1. Centre de Recherche en Neuroscience de Lyon, CNRS UMR5292 - INSERM U1028 - Universite Claude Bernard Lyon 1
2. Unité de Neuroscience, Information et Complexité, CNRS UPR 3293, Gif-sur-Yvette, France 
3. University of California, Berkeley
4. Laboratoire de Neurosciences Intégratives et Adaptatives, CNRS UMR 6149 - Université de Provence, Marseille, France 
5. G-Node, Ludwig-Maximilians-Universität, Munich, Germany 
6. Institut de Neurosciences de la Timone, CNRS UMR 7289 - Université d'Aix-Marseille, Marseille, France
7. Centre de Neurosciences Integratives et Cignitives, UMR 5228 - CNRS - Université Bordeaux I - Université Bordeaux II
8. Neural Information Processing Group, TU Berlin, Germany

If I've somehow missed you off the list I'm very sorry - please let us know.
